@@ -155,10 +155,10 @@ class WebScraper(ABC):
             # Save the scraper result
             if isinstance(this_result, dict):
                 results.append(this_result)
-                index.append(i)
+                index.append(data.index[i])
             elif isinstance(this_result, list):
                 results += this_result
-                index += [i] * len(this_result)
+                index += [data.index[i]] * len(this_result)
             else:
                 raise TypeError("Scraper result must be a dict or list")
 
